@@ -179,6 +179,7 @@ export const LogsPanel = ({
     noInteractions,
     timestampResolution,
     showLogAttributes,
+    unwrappedColumns,
     ...options
   },
   height,
@@ -634,6 +635,7 @@ export const LogsPanel = ({
               timeRange={data.timeRange}
               timestampResolution={timestampResolution}
               timeZone={timeZone}
+              unwrappedColumns={unwrappedColumns}
               wrapLogMessage={wrapLogMessage}
             />
           )}
